@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0101';
 
 use Encode qw(encode_utf8);
 use Crypt::Passphrase::Argon2 ();
@@ -62,7 +62,7 @@ DBIx::Class::EncodedColumn::Crypt::Passphrase::Argon2 - Crypt::Passphrase::Argon
 
 =head1 VERSION
 
-version 0.0100
+version 0.0101
 
 =head1 SYNOPSIS
 
@@ -74,7 +74,7 @@ version 0.0100
       size                => 255,
       encode_column       => 1,
       encode_class        => 'Crypt::Passphrase::Argon2',
-      encode_args         => { cost => 6 },
+      encode_args         => { memory_cost => 256, etc => '...' },
       encode_check_method => 'check_password',
   });
 
@@ -92,12 +92,29 @@ Use L<Crypt::Passphrase::Argon2> for an encoded password column.
 
 =head1 ENCODE ARGUMENTS
 
-=head2 cost
+=head2 memory_cost
 
-A single or double digit non-negative integer representing the cost of the
-hash function.
+Default: C<256>
 
-Default: C<8>
+=head2 time_cost
+
+Default: C<3>
+
+=head2 parallelism
+
+Default: C<1>
+
+=head2 output_size
+
+Default: C<16>
+
+=head2 salt_size
+
+Default: C<16>
+
+=head2 subtype
+
+Default: C<argon2id>
 
 =head1 METHODS
 
